package Bundle::Locale::CLDR::Subsaharanafrica;

use version;

our $VERSION = version->declare('v0.46.0');

=head1 NAME

Bundle::Locale::CLDR::Subsaharanafrica

=head1 CONTENTS

Bundle::Locale::CLDR::Middleafrica 0.46.0

Bundle::Locale::CLDR::Easternafrica 0.46.0

Bundle::Locale::CLDR::Westernafrica 0.46.0

Bundle::Locale::CLDR::Southernafrica 0.46.0


=cut

1;

